package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREnumerated;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;

public class OCSPResponse extends ASN1Encodable {
   OCSPResponseStatus responseStatus;
   ResponseBytes responseBytes;

   public OCSPResponse(OCSPResponseStatus responseStatus, ResponseBytes responseBytes) {
      this.responseStatus = responseStatus;
      this.responseBytes = responseBytes;
   }

   public OCSPResponse(ASN1Sequence seq) {
      this.responseStatus = new OCSPResponseStatus(DEREnumerated.getInstance(seq.getObjectAt(0)));
      if (seq.size() == 2) {
         this.responseBytes = ResponseBytes.getInstance((ASN1TaggedObject)seq.getObjectAt(1), true);
      }

   }

   public static OCSPResponse getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static OCSPResponse getInstance(Object obj) {
      if (obj != null && !(obj instanceof OCSPResponse)) {
         if (obj instanceof ASN1Sequence) {
            return new OCSPResponse((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (OCSPResponse)obj;
      }
   }

   public OCSPResponseStatus getResponseStatus() {
      return this.responseStatus;
   }

   public ResponseBytes getResponseBytes() {
      return this.responseBytes;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.responseStatus);
      ResponseBytes var3;
      if ((var3 = this.responseBytes) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(true, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
